@@ -143,13 +143,18 @@ struct _ioa_engine
   stun_buffer_list bufs;
   SSL_CTX *tls_ctx_ssl23;
   SSL_CTX *tls_ctx_v1_0;
-#if defined(SSL_TXT_TLSV1_1)
+#if TLSv1_1_SUPPORTED
   SSL_CTX *tls_ctx_v1_1;
-#if defined(SSL_TXT_TLSV1_2)
+#if TLSv1_2_SUPPORTED
   SSL_CTX *tls_ctx_v1_2;
 #endif
 #endif
+#if DTLS_SUPPORTED
   SSL_CTX *dtls_ctx;
+#endif
+#if DTLSv1_2_SUPPORTED
+  SSL_CTX *dtls_ctx_v1_2;
+#endif
   turn_time_t jiffie; /* bandwidth check interval */
   ioa_timer_handle timer_ev;
   s08bits cmsg[TURN_CMSG_SZ+1];
@@ -180,7 +185,6 @@ struct _ioa_socket
 	SSL* ssl;
 	u32bits ssl_renegs;
 	int in_write;
-	char orig_ctx_type[16];
 	int bound;
 	int local_addr_known;
 	ioa_addr local_addr;
@@ -251,14 +255,20 @@ ioa_engine_handle create_ioa_engine(super_memory_t *sm,
 
 void set_ssl_ctx(ioa_engine_handle e,
 		SSL_CTX *tls_ctx_ssl23,
-		SSL_CTX *tls_ctx_v1_0,
-#if defined(SSL_TXT_TLSV1_1)
-		SSL_CTX *tls_ctx_v1_1,
-#if defined(SSL_TXT_TLSV1_2)
-		SSL_CTX *tls_ctx_v1_2,
+		SSL_CTX *tls_ctx_v1_0
+#if TLSv1_1_SUPPORTED
+		 ,SSL_CTX *tls_ctx_v1_1
+#if TLSv1_2_SUPPORTED
+		 ,SSL_CTX *tls_ctx_v1_2
 #endif
 #endif
-		SSL_CTX *dtls_ctx);
+#if DTLS_SUPPORTED
+		 ,SSL_CTX *dtls_ctx
+#endif
+#if DTLSv1_2_SUPPORTED
+		,SSL_CTX *dtls_ctx_v1_2
+#endif
+);
 
 void ioa_engine_set_rtcp_map(ioa_engine_handle e, rtcp_map *rtcpmap);
 
